<?php
/**
 * An exception thrown when the decrypted "encrypt" string has an invalid length
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class EncryptInvalidLengthException extends FrameworkException {
	/**
	 * The super constructor for all exceptions
	 *
	 * @param	$message	Error message
	 * @param	$code		Error code
	 * @return	void
	 */
	public function __construct (Filterable $filterInstance, $code) {
		// Get length
		$length = $filterInstance->getConfigInstance()->getConfigEntry('captcha_string_length');

		// Construct message
		$message = sprintf("[%s:%d] Encrypt string has an invalid length. Valid: %d",
			$filterInstance->__toString(),
			$this->getLine(),
			$length
		);

		// Set extra data
		$this->setExtraData($filterInstance->__toString() . ':' . $length);

		// Call parent exception constructor
		parent::__construct($message, $code);
	}
}

// [EOF]
?>
